/**
 * JASMINe
 * Copyright (C) 2009-2011 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EngineStatusVO.as 7874 2011-03-28 09:50:05Z danesa $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.rules.common.vo
{

  import mx.resources.ResourceManager;

  /**
   * Value object that describes the state of a rule engine instance
   *
   * @author Julien Nicoulaud
   *
   */
  [RemoteClass(alias="org.ow2.jasmine.monitoring.eos.rules.common.RuleEngineStatus")]
  [Bindable]
  [ResourceBundle("commonrulesResources")]
  public class EngineStatusVO
  {

    // =====================================================================
    // Variables
    // =====================================================================

    /**
     * The unique name of the rule engine instance
     */
    private var _ruleEngineName : String;

    /**
     * The status of the rule engine
     *
     * @internal Should use a enumerated type
     */
    private var _engineStatus : String;

    /**
     * Some custom details provided by the RuleEngineService
     */
    private var _engineDetails : String;

    private var _deployedPackages : String;

    private var _nbDeployedPackages : int;

    public function get ruleEngineName():String {
      return this._ruleEngineName;
    }

    public function set ruleEngineName(name:String) {
      this._ruleEngineName = name;
    }

    public function get engineStatus():String {
      return this._engineStatus
    }

    public function set engineStatus(status:String) {
      this._engineStatus = status;
    }

    public function get engineDetails():String {
      if (_engineStatus == "IDLE") {
        return ResourceManager.getInstance().getString('commonrulesResources', 'enginedetailsIdle.text');
      } else if (_engineStatus == "RUNNING") {
        return ResourceManager.getInstance().getString('commonrulesResources', 'enginedetailsRunning.text');
      } else if (_engineStatus == "STOPPED") {
        return ResourceManager.getInstance().getString('commonrulesResources', 'enginedetailsStopped.text');
    } else if (_engineStatus == "DISCONNECTED") {
        return ResourceManager.getInstance().getString('commonrulesResources', 'enginedetailsUpdateError.txt');
      } else {
        return ResourceManager.getInstance().getString('commonrulesResources', 'enginedetailsUnknown.text');
      }
    }

    public function set engineDetails(details:String) {
      this._engineDetails = details;
    }

    public function get deployedPackages():String {
      return this._deployedPackages;
    }

    public function set deployedPackages(packages:String) {
      this._deployedPackages = packages;
    }

    public function get nbDeployedPackages():int {
      return this._nbDeployedPackages;
    }

    public function set nbDeployedPackages(nb:int) {
      this._nbDeployedPackages = nb;
    }

  }
}
