/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RHSCodeSnippetVO.as 4869 2009-08-11 11:14:12Z nicoulaj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.rules.common.vo.rulepackage.visual
{

import mx.collections.ArrayCollection;

import org.ow2.jasmine.monitoring.eos.rules.common.vo.rulepackage.AbstractRulePackageMemberVO;

/**
* An element of the RHS part (then) of a rule
*
* @author Julien Nicoulaud
*/
[RemoteClass(alias="org.ow2.jasmine.rules.manager.model.visual.RHSCodeSnippet")]
public class RHSCodeSnippetVO extends AbstractRulePackageMemberVO
                              implements IRHSElementVO
{
	
	// =========================================================================
	// Properties
	// =========================================================================
    
    /**
    * The displayable name of the element type
    */
    public static const RULE_ELEMENT_TYPE_NAME : String = "Code snippet";
    
    /**
    * The description of the element type
    */
    public static const RULE_ELEMENT_TYPE_DESCRIPTION : String =
        "Insert Drools code directly. Warning: use it with caution.";
        
    /**
    * The content
    */
    private var _content : String = "";

    /**
    * The imports
    */
    [ArrayElementType('String')]
    private var _imports : ArrayCollection;

    /**
    * The variables defined in the rule
    */
    [ArrayElementType('String')]
    private var _variables : ArrayCollection;
    
    
    // =========================================================================
    // Getters and setters
    // ========================================================================= 
    
    /**
    * Set the content
    */
    public function set content(value:String):void
    {
        // Store the old value
        var oldValue : Object = _content;
        
        // Assign the value
        _content = value;
        
        // Dispatch a property change event
        notifyPropertyChange("content",oldValue,value);
    }
    
    /**
    * Get the content
    */
    [Bindable]
    public function get content():String
    {
        return _content;
    }
    
    /**
    * Set the imports collection
    */    
    public function set imports(value:ArrayCollection):void
    {
        // Store the old value
        var oldValue : Object = _imports;
        
        // Assign the value
        _imports = value;

        // Dispatch a property change event
        notifyPropertyChange("imports",oldValue,value);
    }
    
    /**
    * Get the imports collection
    */
    [Transient]
    [Bindable]
    public function get imports():ArrayCollection
    {
        // Initialize the property if needed
        if (_imports == null) {
            _imports = new ArrayCollection();
        }
        return _imports;
    }
    
    /**
    * Set the variables collection
    */    
    public function set variables(value:ArrayCollection):void
    {
        // Store the old value
        var oldValue : Object = _variables;
        
        // Assign the value
        _variables = value;

        // Dispatch a property change event
        notifyPropertyChange("variables",oldValue,value);
    }
    
    /**
    * Get the variables collection
    */
    [Transient]
    [Bindable]
    public function get variables():ArrayCollection
    {
        // Initialize the property if needed
        if (_variables == null) {
            _variables = new ArrayCollection();
        }
        return _variables;
    }
	
    
    // =========================================================================
    // Implementation of IRuleElementVO
    // =========================================================================
    
    /**
    * The displayable name of the element type
    */    
    public function getName():String
    {
        return RULE_ELEMENT_TYPE_NAME;
    }
        
    /**
    * The description of the element type
    */
    public function getDescription():String
    {
        return RULE_ELEMENT_TYPE_DESCRIPTION;
    }
    
    	
    // =========================================================================
    // Implementation of IRulePackageVO
    // =========================================================================
    
    /**
    * Get the generated source in Drools syntax
    */
    override public function getDrlSource():String
    {
        return content;
    }
}
}
